[][src]Function browser_window_core::prelude::cbw_Window_getTitle

pub unsafe extern "C" fn cbw_Window_getTitle(
    window: *mut cbw_Window,
    title: cbw_StrSlice
) -> u64

Copies as many bytes into title that fit in there. Returns the number of characters the title actually has.