[−][src]Function browser_window_core::prelude::cbw_string_freeCstr
pub unsafe extern "C" fn cbw_string_freeCstr(str_: *mut i8)
Frees the string allocated with any of the functions of this module.
pub unsafe extern "C" fn cbw_string_freeCstr(str_: *mut i8)
Frees the string allocated with any of the functions of this module.