[−][src]Trait browser_window_core::application::ApplicationExt
Required methods
fn assert_correct_thread(&self)
Asserts if not on the GUI thread
fn dispatch(
&self,
work: unsafe fn(_: ApplicationImpl, _: *mut ()),
data: *mut ()
) -> bool
&self,
work: unsafe fn(_: ApplicationImpl, _: *mut ()),
data: *mut ()
) -> bool
Dispatches work to be executed on the GUI thread.
fn exit(&self, exit_code: i32)
Causes the main loop to exit and lets it return the given code.
fn exit_threadsafe(&self, exit_code: i32)
Same as exit, but is thread-safe.
fn initialize(
argc: c_int,
argv: *mut *mut c_char,
settings: &ApplicationSettings
) -> ApplicationImpl
argc: c_int,
argv: *mut *mut c_char,
settings: &ApplicationSettings
) -> ApplicationImpl
fn run(
&self,
on_ready: unsafe fn(_: ApplicationImpl, _: *mut ()),
data: *mut ()
) -> i32
&self,
on_ready: unsafe fn(_: ApplicationImpl, _: *mut ()),
data: *mut ()
) -> i32
Runs the main loop. This blocks until the application is exitting.
Provided methods
fn finish(&self)
Shuts down all application processes and performs necessary clean-up code.
Implementors
impl ApplicationExt for ApplicationImpl[src]
fn assert_correct_thread(&self)[src]
fn dispatch(
&self,
work: unsafe fn(_: ApplicationImpl, _: *mut ()),
_data: *mut ()
) -> bool[src]
&self,
work: unsafe fn(_: ApplicationImpl, _: *mut ()),
_data: *mut ()
) -> bool
fn exit(&self, exit_code: i32)[src]
fn exit_threadsafe(&self, exit_code: i32)[src]
fn finish(&self)[src]
fn initialize(
argc: c_int,
argv: *mut *mut c_char,
_settings: &ApplicationSettings
) -> Self[src]
argc: c_int,
argv: *mut *mut c_char,
_settings: &ApplicationSettings
) -> Self
fn run(
&self,
on_ready: unsafe fn(_: ApplicationImpl, _: *mut ()),
_data: *mut ()
) -> i32[src]
&self,
on_ready: unsafe fn(_: ApplicationImpl, _: *mut ()),
_data: *mut ()
) -> i32